@@ -2,6 +2,8 @@
 from __future__ import unicode_literals
 
 from django import template
+from django.conf import settings
+from django.contrib.sites.models import Site
 from django.db.models import Model
 
 try:
@@ -18,11 +20,19 @@ def compile_text(context, text):
     return template.Template(text).render(ctx)
 
 
-@register.inclusion_tag('django_social_share/templatetags/post_to_twitter.html', takes_context = True)
+class MockRequest(object):
+    def build_absolute_uri(self, relative_url):
+        if relative_url.startswith('http'):
+            return relative_url
+        current_site = Site.objects.get_current()
+        return '%s%s' % (current_site.domain, relative_url)
+
+
+@register.inclusion_tag('django_social_share/templatetags/post_to_twitter.html', takes_context=True)
 def post_to_twitter(context, text, obj_or_url=None, link_text='Post to Twitter'):
     text = compile_text(context, text)
-    request = context['request']
     context['link_text'] = link_text
+    request = context.get('request', MockRequest())
 
     if obj_or_url is not None:
         if isinstance(obj_or_url, Model):
@@ -43,10 +53,10 @@ def post_to_twitter(context, text, obj_or_url=None, link_text='Post to Twitter')
     return context
 
 
-@register.inclusion_tag('django_social_share/templatetags/post_to_facebook.html', takes_context = True)
+@register.inclusion_tag('django_social_share/templatetags/post_to_facebook.html', takes_context=True)
 def post_to_facebook(context, obj_or_url=None, link_text='Post to Facebook'):
-    request = context['request']
     context['link_text'] = link_text
+    request = context.get('request', MockRequest())
 
     if obj_or_url is not None:
         if isinstance(obj_or_url, Model):
